@@ -41,7 +41,7 @@ bool LinearMotorCreator::sceneEvent(QEvent* event)
         _worldModel->beginMacro(i18n("Create %1", _worldModel->newItemName(_className)));
         _item = _worldModel->createItem(className()); Q_ASSERT(_item != NULL);
 
-        _worldModel->setProperty(_item, "localPosition", vpos);
+        _worldModel->setProperty(_item, QStringLiteral("localPosition"), vpos);
         _worldModel->addItem(_item);
         tryAttach(pos);
 
@@ -60,14 +60,14 @@ void LinearMotorCreator::tryAttach(const QPointF& pos)
     foreach(QGraphicsItem* it, _worldScene->items(pos)) {
         StepCore::Item* item = _worldScene->itemFromGraphics(it);
         if(dynamic_cast<StepCore::Particle*>(item) || dynamic_cast<StepCore::RigidBody*>(item)) {
-            _worldModel->setProperty(_item, "body",
+            _worldModel->setProperty(_item, QStringLiteral("body"),
                  QVariant::fromValue<StepCore::Object*>(item), WorldModel::UndoNoMerge);
 
             StepCore::Vector2d lPos(0, 0);
             if(dynamic_cast<StepCore::RigidBody*>(item))
                 lPos = dynamic_cast<StepCore::RigidBody*>(item)->pointWorldToLocal(StepGraphicsItem::pointToVector(pos));
 
-            _worldModel->setProperty(_item, "localPosition", QVariant::fromValue(lPos));
+            _worldModel->setProperty(_item, QStringLiteral("localPosition"), QVariant::fromValue(lPos));
             break;
         }
     }
@@ -82,7 +82,7 @@ LinearMotorGraphicsItem::LinearMotorGraphicsItem(StepCore::Item* item, WorldMode
     setZValue(HANDLER_ZVALUE);
 
     _forceHandler = new ArrowHandlerGraphicsItem(item, worldModel, this,
-                   _item->metaObject()->property("forceValue"));
+                   _item->metaObject()->property(QStringLiteral("forceValue")));
     _forceHandler->setVisible(false);
 }
 
@@ -109,11 +109,11 @@ void LinearMotorGraphicsItem::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
         if(!_moving) {
             _moving = true;
             _worldModel->beginMacro(i18n("Move %1", _item->name()));
-            _worldModel->setProperty(_item, "body",
+            _worldModel->setProperty(_item, QStringLiteral("body"),
                         QVariant::fromValue<StepCore::Object*>(NULL), WorldModel::UndoNoMerge);
         }
 
-        _worldModel->setProperty(_item, "localPosition", vpos);
+        _worldModel->setProperty(_item, QStringLiteral("localPosition"), vpos);
     } else {
         event->ignore();
     }
@@ -127,14 +127,14 @@ void LinearMotorGraphicsItem::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
             StepCore::Item* item = static_cast<WorldScene*>(scene())->itemFromGraphics(it);
             if(dynamic_cast<StepCore::Particle*>(item) || dynamic_cast<StepCore::RigidBody*>(item)) {
                 _worldModel->simulationPause();
-                _worldModel->setProperty(_item, "body",
+                _worldModel->setProperty(_item, QStringLiteral("body"),
                             QVariant::fromValue<StepCore::Object*>(item), WorldModel::UndoNoMerge);
 
                 StepCore::Vector2d lPos(0, 0);
                 if(dynamic_cast<StepCore::RigidBody*>(item))
                     lPos = dynamic_cast<StepCore::RigidBody*>(item)->pointWorldToLocal(StepGraphicsItem::pointToVector(pos));
 
-                _worldModel->setProperty(_item, "localPosition", QVariant::fromValue(lPos));
+                _worldModel->setProperty(_item, QStringLiteral("localPosition"), QVariant::fromValue(lPos));
 
                 break;
             }
@@ -222,7 +222,7 @@ bool CircularMotorCreator::sceneEvent(QEvent* event)
         _worldModel->beginMacro(i18n("Create %1", _worldModel->newItemName(_className)));
         _item = _worldModel->createItem(className()); Q_ASSERT(_item != NULL);
 
-        _worldModel->setProperty(_item, "localPosition", vpos);
+        _worldModel->setProperty(_item, QStringLiteral("localPosition"), vpos);
         _worldModel->addItem(_item);
         tryAttach(pos);
 
@@ -241,12 +241,12 @@ void CircularMotorCreator::tryAttach(const QPointF& pos)
     foreach(QGraphicsItem* it, _worldScene->items(pos)) {
         StepCore::Item* item = _worldScene->itemFromGraphics(it);
         if(dynamic_cast<StepCore::RigidBody*>(item)) {
-            _worldModel->setProperty(_item, "body",
+            _worldModel->setProperty(_item, QStringLiteral("body"),
                     QVariant::fromValue<StepCore::Object*>(item), WorldModel::UndoNoMerge);
 
             StepCore::Vector2d lPos(0, 0);
             lPos = dynamic_cast<StepCore::RigidBody*>(item)->pointWorldToLocal(StepGraphicsItem::pointToVector(pos));
-            _worldModel->setProperty(_item, "localPosition", QVariant::fromValue(lPos));
+            _worldModel->setProperty(_item, QStringLiteral("localPosition"), QVariant::fromValue(lPos));
             break;
         }
     }
@@ -259,7 +259,7 @@ CircularMotorGraphicsItem::CircularMotorGraphicsItem(StepCore::Item* item, World
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
     _torqueHandler = new CircularArrowHandlerGraphicsItem(item, worldModel,  this, ARROW_RADIUS,
-                   _item->metaObject()->property("torqueValue"));
+                   _item->metaObject()->property(QStringLiteral("torqueValue")));
     _torqueHandler->setVisible(false);
     setZValue(HANDLER_ZVALUE);
 }
@@ -287,11 +287,11 @@ void CircularMotorGraphicsItem::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
         if(!_moving) {
             _moving = true;
             _worldModel->beginMacro(i18n("Move %1", _item->name()));
-            _worldModel->setProperty(_item, "body",
+            _worldModel->setProperty(_item, QStringLiteral("body"),
                     QVariant::fromValue<StepCore::Object*>(NULL), WorldModel::UndoNoMerge);
         }
 
-        _worldModel->setProperty(_item, "localPosition", vpos);
+        _worldModel->setProperty(_item, QStringLiteral("localPosition"), vpos);
     } else {
         event->ignore();
     }
@@ -305,14 +305,14 @@ void CircularMotorGraphicsItem::mouseReleaseEvent(QGraphicsSceneMouseEvent *even
             StepCore::Item* item = static_cast<WorldScene*>(scene())->itemFromGraphics(it);
             if(dynamic_cast<StepCore::RigidBody*>(item)) {
                 _worldModel->simulationPause();
-                _worldModel->setProperty(_item, "body",
+                _worldModel->setProperty(_item, QStringLiteral("body"),
                         QVariant::fromValue<StepCore::Object*>(item), WorldModel::UndoNoMerge);
 
                 StepCore::Vector2d lPos(0, 0);
                 if(dynamic_cast<StepCore::RigidBody*>(item))
                     lPos = dynamic_cast<StepCore::RigidBody*>(item)->pointWorldToLocal(StepGraphicsItem::pointToVector(pos));
 
-                _worldModel->setProperty(_item, "localPosition", QVariant::fromValue(lPos));
+                _worldModel->setProperty(_item, QStringLiteral("localPosition"), QVariant::fromValue(lPos));
 
                 break;
             }
